CalendarHelper class
날짜 및 캘린더 관련 유틸리티 함수를 제공하는 헬퍼 클래스
주요 기능:
- 월의 첫 요일 및 마지막 날짜 계산
- 월/요일 이름 변환
- DateTime ↔ String 변환
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dateTimeToString(
DateTime date) → String - DateTime을 문자열로 변환합니다.
-
getCurrentDate(
) → DateTime - 현재 날짜를 반환합니다.
-
getFirstWeekday(
int year, int month) → int - 특정 년도, 월의 시작 요일을 반환합니다.
-
getLastDay(
int year, int month) → int - 특정 년도, 월의 마지막 날짜를 반환합니다.
-
getMonthInfo(
int year, int month) → Map< String, int> - 특정 년도, 월의 시작 요일과 마지막 날짜를 반환합니다.
-
getMonthNameShort(
int month) → String - 월 숫자를 영어 약어(3글자)로 변환합니다.
-
getWeekdayName(
int weekday) → String - 요일 숫자를 영어 약어로 변환합니다.
-
stringToDateTime(
String date) → DateTime - 문자열을 DateTime으로 변환합니다.